Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Ultimaker/Cura.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorluz paz <luzpaz@users.noreply.github.com>2021-09-07 18:34:22 +0300
committerluz paz <luzpaz@users.noreply.github.com>2021-09-07 18:34:22 +0300
commit9b203c834a4c9943d68b98a72ddeff6f99bbe164 (patch)
tree1d37e87feebb2aca8994b08625e0fffcb4686811 /plugins
parentd68f375e386049878de69eb0b33aacc3f40cb344 (diff)
Fix source typos
Diffstat (limited to 'plugins')
-rw-r--r--plugins/PostProcessingPlugin/scripts/ChangeAtZ.py22
-rw-r--r--plugins/SimulationView/LayerSlider.qml2
2 files changed, 12 insertions, 12 deletions
diff --git a/plugins/SimulationView/LayerSlider.qml b/plugins/SimulationView/LayerSlider.qml
index e8d5e2f315..d2a22755ae 100644
--- a/plugins/SimulationView/LayerSlider.qml
+++ b/plugins/SimulationView/LayerSlider.qml
@@ -300,7 +300,7 @@ Item
// don't allow the upper handle to be lower than the lower handle
if (y - (upperHandle.y + upperHandle.height) < sliderRoot.minimumRangeHandleSize)
{
- upperHandle.y = y - (upperHandle.heigth + sliderRoot.minimumRangeHandleSize)
+ upperHandle.y = y - (upperHandle.height + sliderRoot.minimumRangeHandleSize)
}
// update the range handle
diff --git a/plugins/PostProcessingPlugin/scripts/ChangeAtZ.py b/plugins/PostProcessingPlugin/scripts/ChangeAtZ.py
index 9e94dd9828..712af63b07 100644
--- a/plugins/PostProcessingPlugin/scripts/ChangeAtZ.py
+++ b/plugins/PostProcessingPlugin/scripts/ChangeAtZ.py
@@ -1367,11 +1367,11 @@ class ChangeAtZProcessor:
# handle extruder temp changes
if command.command == "M104" or command.command == "M109":
- # get our tempurature
- tempurature = command.getArgumentAsFloat("S")
+ # get our temperature
+ temperature = command.getArgumentAsFloat("S")
- # don't bother if we don't have a tempurature
- if tempurature is None:
+ # don't bother if we don't have a temperature
+ if temperature is None:
return
# get our extruder, default to extruder one
@@ -1379,10 +1379,10 @@ class ChangeAtZProcessor:
# set our extruder temp based on the extruder
if extruder is None or extruder == 0:
- self.lastValues["extruderOne"] = tempurature
+ self.lastValues["extruderOne"] = temperature
if extruder is None or extruder == 1:
- self.lastValues["extruderTwo"] = tempurature
+ self.lastValues["extruderTwo"] = temperature
# move to the next command
return
@@ -1401,10 +1401,10 @@ class ChangeAtZProcessor:
if command.command == "M221":
# get our flow rate
- tempurature = command.getArgumentAsFloat("S")
+ temperature = command.getArgumentAsFloat("S")
# don't bother if we don't have a flow rate (for some reason)
- if tempurature is None:
+ if temperature is None:
return
# get our extruder, default to global
@@ -1412,11 +1412,11 @@ class ChangeAtZProcessor:
# set our extruder temp based on the extruder
if extruder is None:
- self.lastValues["flowrate"] = tempurature
+ self.lastValues["flowrate"] = temperature
elif extruder == 1:
- self.lastValues["flowrateOne"] = tempurature
+ self.lastValues["flowrateOne"] = temperature
elif extruder == 1:
- self.lastValues["flowrateTwo"] = tempurature
+ self.lastValues["flowrateTwo"] = temperature
# move to the next command
return